<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Guto Lite
 */

get_header();

get_template_part( 'template-parts/header/content', 'blog-header' );

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );

$blog_sidebar = guto_lite_option( 'blog_sidebar' );

$blog_style = guto_lite_option( 'blog_style' );

$pagination_style = guto_lite_option( 'pagination_style' );

$show_blog_pagination = guto_lite_option( 'show_blog_pagination' );

if( $blog_style == 'style-1' || $blog_style == 'style-2' || $blog_style == '' ) :
    $blog_style_class = 'blog-area ptb-100';
    $blog_style_container = 'container';
elseif( $blog_style == 'style-6' ) :
    $blog_style_class = 'oet-blog-area ptb-100';
    $blog_style_container = 'container';
else:
    $blog_style_class = 'blog-area ptb-100';
    $blog_style_container = 'container';
endif;

if ( $guto_lite_current_demo == 'digital-marketing' ):
    $blog_style_class = 'dm-blog-area pt-100 pb-100';
elseif($guto_lite_current_demo == 'coworking-space' ):
    $blog_style_class = 'cws-blog-area ptb-100';
elseif($guto_lite_current_demo == 'motivational-speaker' ):
    $blog_style_class = 'ms-blog-area pt-100 pb-70';
    $blog_style_container = 'container-lg';
elseif($guto_lite_current_demo == 'life-coaching' ):
    $blog_style_class = 'lc-blog-area pt-100 pb-70';
    $blog_style_container = 'container-lg';
elseif($guto_lite_current_demo == 'lifestyle-blog' ):
    $blog_style_class = 'fls-week-area ptb-100';
endif;
?>
    <!-- Start Blog Area -->
    <div id="content" class="<?php echo esc_attr( $blog_style_class ); ?>">
        <div class="<?php echo esc_attr( $blog_style_container ); ?>">
            <div class="row">
                <?php if( $blog_sidebar == 'left' ): ?>
                    <?php get_sidebar(); ?>
                <?php endif; ?>
                <!-- Start Blog Content -->
                <div class="<?php echo esc_attr( guto_lite_blog_sidebar() ); ?>">
                    <?php
                    if ( have_posts() ) :
                        get_template_part( 'template-parts/content', get_post_format());
                    else :
                        get_template_part( 'template-parts/content', 'none' );
                    endif;

                    if ( $guto_lite_current_demo == 'digital-marketing'): ?>
                        <div class="dm-pagination-area">
                            <nav aria-label="navigation">
                            <?php echo wp_kses_post(paginate_links( array(
                                    'format' => '?paged=%#%',
                                    'prev_text' => '<i class="bx bx-chevron-left"></i>',
                                    'next_text' => '<i class="bx bx-chevron-right"></i>',
                                    )
                                ) );
                            ?>
                            </nav>
                        </div>
                    <?php elseif ( $guto_lite_current_demo == 'coworking-space'): ?>
                        <div class="cws-pagination-area">
                            <div class="nav-links">
                                <?php echo wp_kses_post(paginate_links( array(
                                    'format' => '?paged=%#%',
                                        'prev_text' => '<i class="bx bx-left-arrow-alt"></i>',
                                        'next_text' => '<i class="bx bx-right-arrow-alt"></i>',
                                        )
                                    ) );
                                ?>
                            </div>
                        </div>
                    <?php elseif ( $guto_lite_current_demo == 'freelancer'): ?>
                        <div class="col-lg-12 col-md-12 col-sm-12">
                            <div class="fl-pagination-area">
                                <div class="nav-links">
                                    <?php echo wp_kses_post(paginate_links( array(
                                        'format' => '?paged=%#%',
                                            'prev_text' => '<i class="bx bx-left-arrow-alt"></i>',
                                            'next_text' => '<i class="bx bx-right-arrow-alt"></i>',
                                            )
                                        ) );
                                    ?>
                                </div>
                            </div>
                        </div>
                    <?php elseif ($guto_lite_current_demo == 'motivational-speaker' ):
                        if(  $show_blog_pagination ) : ?>
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="ms-pagination-area">
                                    <div class="nav-links">
                                        <?php echo wp_kses_post(paginate_links( array(
                                            'format' => '?paged=%#%',
                                                'prev_text' => '<i class="bx bx-left-arrow-alt"></i>',
                                                'next_text' => '<i class="bx bx-right-arrow-alt"></i>',
                                                )
                                            ) );
                                        ?>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php elseif ($guto_lite_current_demo == 'life-coaching') :
                        if(  $show_blog_pagination ):?>
                            <div class="col-lg-12 col-md-12 col-sm-12">
                                <div class="lc-pagination-area">
                                    <div class="nav-links">
                                        <?php echo wp_kses_post(paginate_links( array(
                                            'format' => '?paged=%#%',
                                                'prev_text' => '<i class="bx bx-left-arrow-alt"></i>',
                                                'next_text' => '<i class="bx bx-right-arrow-alt"></i>',
                                                )
                                            ) );
                                        ?>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php elseif ( $guto_lite_current_demo == 'recipe-blog'): ?>
                        <div class="rb-pagination-area">
                            <div class="nav-links">
                                <?php echo wp_kses_post(paginate_links( array(
                                    'format' => '?paged=%#%',
                                        'prev_text' => '<i class="bx bx-chevron-left"></i>',
                                        'next_text' => '<i class="bx bx-chevron-right"></i>',
                                        )
                                    ) );
                                ?>
                            </div>
                        </div>
                    <?php elseif ( $guto_lite_current_demo == 'lifestyle-blog'): ?>
                        <div class="fls-pagination-area">
                            <div class="nav-links">
                                <?php echo wp_kses_post(paginate_links( array(
                                    'format' => '?paged=%#%',
                                        'prev_text' => '<i class="bx bx-left-arrow-alt"></i>',
                                        'next_text' => '<i class="bx bx-right-arrow-alt"></i>',
                                        )
                                    ) );
                                ?>
                            </div>
                        </div>
                    <?php elseif ( $guto_lite_current_demo == 'online-health-coach'): ?>
                        <div class="ohc-pagination-area">
                            <div class="nav-links">
                                <?php echo wp_kses_post(paginate_links( array(
                                    'format' => '?paged=%#%',
                                        'prev_text' => '<i class="bx bx-left-arrow-alt"></i>',
                                        'next_text' => '<i class="bx bx-right-arrow-alt"></i>',
                                        )
                                    ) );
                                ?>
                            </div>
                        </div>
                    <?php elseif( $pagination_style == 'style-2' ) : ?>
                        <div class="col-lg-12">
                            <div class="os-pagination-area">
                                <nav aria-label="navigation">
                                <?php echo wp_kses_post(paginate_links( array(
                                    'format' => '?paged=%#%',
                                    'prev_text' => '<i class="flaticon-left-arrow"></i>',
                                    'next_text' => '<i class="flaticon-right-arrow-1"></i>',
                                        )
                                    ) );
                                ?>
                                </nav>
                            </div>
                        </div>
                    <?php elseif( $pagination_style == 'style-3' ) : ?>
                        <div class="col-lg-12">
                            <div class="restaurant-pagination-area">
                                <nav aria-label="navigation">
                                <?php echo wp_kses_post(paginate_links( array(
                                    'format' => '?paged=%#%',
                                    'prev_text' => '<i class="flaticon-left-arrow"></i>',
                                    'next_text' => '<i class="flaticon-right-arrow-1"></i>',
                                        )
                                    ) );
                                ?>
                                </nav>
                            </div>
                        </div>
                    <?php elseif( $pagination_style == 'style-4' ) : ?>
                        <!-- Stat Pagination -->
                        <div class="col-lg-12 col-md-12">
                            <div class="insurance-pagination-area">
                                <div class="nav-links">
                                <?php echo wp_kses_post(paginate_links( array(
                                    'format' => '?paged=%#%',
                                    'prev_text' => '<i class="bx bx-left-arrow-alt"></i>',
                                    'next_text' => '<i class="bx bx-right-arrow-alt"></i>',
                                        )
                                    ) );
                                ?>
                                </div>
                            </div>
                        </div>
                    <?php elseif( $pagination_style == 'style-1' || $pagination_style == '' ) : ?>
                        <?php if ( $guto_lite_current_demo == 'online-education'): ?>
                            <div class="col-lg-12 col-md-12">
                                <div class="oet-pagination-area">
                                    <div class="nav-links">
                                        <?php echo wp_kses_post(paginate_links( array(
                                            'format' => '?paged=%#%',
                                            'prev_text' => '<i class="bx bx-chevron-left"></i>',
                                            'next_text' => '<i class="bx bx-chevron-right"></i>',
                                                )
                                            ) );
                                        ?>
                                    </div>
                                </div>
                            </div>
                        <?php else: ?>
                            <div class="pagination-area text-center">
                                <nav aria-label="navigation">
                                <?php echo wp_kses_post(paginate_links( array(
                                    'format' => '?paged=%#%',
                                    'prev_text' => '<i class="bx bx-chevron-left"></i>',
                                    'next_text' => '<i class="bx bx-chevron-right"></i>',
                                        )
                                    ) );
                                ?>
                                </nav>
                            </div>
                        <?php endif; ?>
                    <?php endif; ?>
                </div>
                <!-- End Blog Content -->

                <?php if( $blog_sidebar == 'right' ): ?>
                    <?php get_sidebar(); ?>
                <?php endif; ?>
            </div>
        </div>
    </div>
    <!-- End Blog Area -->

<?php

if ( $guto_lite_current_demo == 'online-health-coach'):
    $is_ohc_cta  = guto_lite_option('is_ohc_cta');
    $is_ohc_contact  = guto_lite_option('is_ohc_contact');

    if( $is_ohc_cta ):
        get_template_part( 'template-parts/footer/footer','cta-ohc' );
    endif;

    if( $is_ohc_contact ):
        get_template_part( 'template-parts/footer/footer','contact-info-ohc' );
    endif;
endif;

get_footer();
