<?php
/**
 * Template for displaying content of archive courses page.
 *
 * @author  ThimPress
 * @package LearnPress/Templates
 * @version 4.0.0
 */

defined( 'ABSPATH' ) || exit;

/**
 * @since 4.0.0
 *
 * @see LP_Template_General::template_header()
 */
do_action( 'learn-press/template-header' );

global $post, $wp_query, $lp_tax_query, $wp_query;

get_template_part( 'template-parts/header/content', 'course-header' );

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );

if( $guto_lite_current_demo == 'motivational-speaker' ) :
    $guto_course_area = 'ms-courses-area';
    $guto_pagination_area = 'ms-pagination-area';
elseif( $guto_lite_current_demo == 'life-coaching' ) :
    $guto_course_area = 'lc-courses-area';
    $guto_pagination_area = 'lc-pagination-area';
endif;


$post_ids = array();

$query = new LP_Query_Course( array( 'post__in' => $post_ids) );
$args  = $query->get_wp_query_vars();

$query = new WP_Query( $args );

if( $guto_lite_current_demo == 'motivational-speaker' || $guto_lite_current_demo == 'life-coaching' ) : ?>
	<div class="<?php echo esc_attr( $guto_course_area ); ?> ptb-100">
		<div class="container-lg">
			<div class="row">
				<?php if ( is_active_sidebar( 'course-sidebar' ) ): ?>
					<div class="col-lg-8 col-md-12">
				<?php else: ?>
					<div class="col-lg-12 col-md-12">
				<?php endif; ?>
					<div class="row justify-content-center">
					<?php
					if ( $query->have_posts() ) :
						/**
						 * LP Hook
						 */
						do_action( 'learn-press/shortcode/before-courses-loop' );

						LP()->template( 'course' )->begin_courses_loop();

						while ( $query->have_posts() ) :
							$query->the_post();

							learn_press_get_template_part( 'content', 'course' );

						endwhile;

						LP()->template( 'course' )->end_courses_loop();

						/**
						 * LP Hook
						 */
						do_action( 'learn-press/shortcode/after-main-content' );
						wp_reset_postdata();
					else :
						_e( 'No courses', 'learnpress' );
					endif;
					?>
					</div>
				</div>

				<?php if ( is_active_sidebar( 'course-sidebar' ) ): ?>
					<div class="col-lg-4 col-md-12">
						<div id="secondary" class="sidebar">
							<?php do_action( 'learn-press/sidebar' );?>
						</div>
					</div>
				<?php endif; ?>
			</div>
			<div class="col-lg-12 col-md-12 col-sm-12">
				<div class="<?php echo esc_attr( $guto_pagination_area ); ?>">
					<div class="nav-links">
						<?php echo wp_kses_post(paginate_links( array(
							'format' => '?paged=%#%',
								'prev_text' => '<i class="bx bx-left-arrow-alt"></i>',
								'next_text' => '<i class="bx bx-right-arrow-alt"></i>',
								)
							) );
						?>
					</div>
				</div>
			</div>
		</div>
	</div>
<?php elseif( $guto_lite_current_demo == 'online-health-coach' ): ?>
	<div class="ohc-courses-area bg-top pt-100 pb-100">
		<div class="container">
			<div class="row">
				<?php if ( is_active_sidebar( 'course-sidebar' ) ): ?>
					<div class="col-lg-8 col-md-12">
				<?php else: ?>
					<div class="col-lg-12 col-md-12">
				<?php endif; ?>
					<div class="row justify-content-center">
						<?php
						LP()->template( 'course' )->begin_courses_loop();
						while ( have_posts() ) :
							the_post();

								learn_press_get_template_part( 'content', 'course' );

						endwhile;

						LP()->template( 'course' )->end_courses_loop();

						/**
						* @since 3.0.0
						*/
						do_action( 'learn-press/after-courses-loop' );
						?>
					</div>
				</div>

				<?php if ( is_active_sidebar( 'course-sidebar' ) ): ?>
					<div class="col-lg-4 col-md-12">
						<div id="secondary" class="sidebar">
							<?php do_action( 'learn-press/sidebar' );?>
						</div>
					</div>
				<?php endif; ?>
			</div>
		</div>
	</div>
<?php else: ?>
	<div class="oet-courses-area ptb-100">
		<div class="container">
			<div class="row">
				<?php if ( is_active_sidebar( 'course-sidebar' ) ): ?>
					<div class="col-lg-8 col-md-12">
				<?php else: ?>
					<div class="col-lg-12 col-md-12">
				<?php endif; ?>
					<?php
					LP()->template( 'course' )->begin_courses_loop();
					while ( have_posts() ) :
						the_post();

							learn_press_get_template_part( 'content', 'course' );

					endwhile;

					LP()->template( 'course' )->end_courses_loop();

					/**
					* @since 3.0.0
					*/
					do_action( 'learn-press/after-courses-loop' );
					?>
				</div>

				<?php if ( is_active_sidebar( 'course-sidebar' ) ): ?>
					<div class="col-lg-4 col-md-12">
						<div id="secondary" class="sidebar">
							<?php do_action( 'learn-press/sidebar' );?>
						</div>
					</div>
				<?php endif; ?>
			</div>
		</div>
	</div>
<?php endif; ?>

<?php

if ( $guto_lite_current_demo == 'online-health-coach'):
    $is_ohc_cta  = guto_lite_option('is_ohc_cta');
    $is_ohc_contact  = guto_lite_option('is_ohc_contact');

    if( $is_ohc_cta ):
        get_template_part( 'template-parts/footer/footer','cta-ohc' );
    endif;

    if( $is_ohc_contact ):
        get_template_part( 'template-parts/footer/footer','contact-info-ohc' );
    endif;
endif;

/**
 * @since 4.0.0
 *
 * @see   LP_Template_General::template_footer()
 */
do_action( 'learn-press/template-footer' );