<?php
/**
 * Template for displaying course content within the loop.
 *
 * This template can be overridden by copying it to guto-lite/learnpress/content-course.php
 *
 * @author  EnvyTheme
 * @package LearnPress/Templates
 * @version 4.0.0
 */

/**
 * Prevent loading this file directly
 */
defined( 'ABSPATH' ) || exit();

$course = LP_Global::course();
$user   = LP_Global::user();

$course_students        = guto_lite_option( 'course_students' );
$course_page_lessons    = guto_lite_option( 'course_page_lessons' );

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );

if( $guto_lite_current_demo == 'motivational-speaker' ) :
    $guto_single_courses_box = 'single-ms-courses-box';
elseif( $guto_lite_current_demo == 'life-coaching' ) :
    $guto_single_courses_box = 'single-lc-courses-box';
endif;

if( $guto_lite_current_demo == 'motivational-speaker' || $guto_lite_current_demo == 'life-coaching' ) : ?>
    <div <?php post_class('col-lg-4 col-md-6'); ?>>
        <div class="<?php echo esc_attr( $guto_single_courses_box ); ?>">
            <a href="<?php the_permalink(); ?>" class="image d-block">
                <img src="<?php the_post_thumbnail_url('guto_banner_course'); ?>" alt="<?php the_post_thumbnail_caption(); ?>">
            </a>
            <div class="content">
                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                <ul class="courses-box-list d-flex align-items-center justify-content-between">
                    <li><i class='bx bx-book'></i>                                             <?php echo $course->get_curriculum_items( 'lp_lesson' ) ? count( $course->get_curriculum_items( 'lp_lesson' ) ) : 0; ?></li>

                    <?php $user_count = $course->get_users_enrolled() ? $course->get_users_enrolled() : 0; ?>
                    <li>
                        <i class='bx bx-group'></i>
                        <?php echo esc_html( $user_count ); ?>
                    </li>
                </ul>
                <ul class="courses-box-footer d-flex align-items-center justify-content-between">
                    <li>
                        <div class="author">
                            <div class="d-flex align-items-center justify-content-center">
                                <?php printf($course->get_instructor()->get_profile_picture()); ?>
                                <span>
                                    <?php if(get_the_author() == ''): ?>
                                        <?php $current_user = wp_get_current_user();
                                        echo esc_html( $current_user->display_name );; ?>
                                    <?php else: ?>
                                        <?php printf($course->get_instructor_html()); ?>
                                    <?php endif; ?>
                                </span>
                            </div>
                        </div>
                    </li>
                    <?php $price_html = $course->get_price_html(); if ( $price_html ) : ?>
                        <li>
                            <?php if ( $course->get_origin_price() != $course->get_price() ) : ?>
                                <div class="price-new">
                                    <span class="origin-price"><?php echo esc_html( $course->get_origin_price_html() ); ?></span>
                                    <span>
                                        <del><?php echo esc_html( $price_html ); ?></del>
                                    </span>
                                </div>
                            <?php else : ?>
                                <div class="price">
                                    <span><?php echo esc_html( $price_html ); ?></span>
                                </div>
                            <?php endif; ?>
                        </li>
                    <?php endif; ?>
                </ul>
            </div>
        </div>
    </div>
<?php elseif( $guto_lite_current_demo == 'online-health-coach' ) : ?>
    <div id="post-<?php the_ID(); ?>" class="col-lg-4 col-md-6 profile-page-extra-content-remove">
        <?php do_action( 'learn-press/before-courses-loop-item' ); ?>

        <div class="ohc-single-courses">
            <div class="courses-image">
                <a href="<?php the_permalink(); ?>"><img src="<?php the_post_thumbnail_url('guto_course_size_775_500'); ?>" alt="<?php the_post_thumbnail_caption(); ?>"></a>
            </div>

            <div class="courses-content">
                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>

                <?php if($course_students != '' || $course_page_lessons != ''): ?>
                    <ul class="courses-box-list d-flex align-items-center justify-content-between">
                        <?php if($course_students != ''): ?>
                            <?php $user_count = $course->get_users_enrolled() ? $course->get_users_enrolled() : 0; ?>
                            <li><i class='bx bx-book'></i> <?php echo esc_html( $user_count ); ?>  <?php echo esc_html( $course_students ); ?></li>
                        <?php endif; ?>

                        <?php if($course_page_lessons != ''): ?>
                            <li><i class='bx bx-group'></i> <?php echo esc_html($course->get_curriculum_items( 'lp_lesson' )) ? count( $course->get_curriculum_items( 'lp_lesson' ) ) : 0; ?>   <?php echo esc_html( $course_page_lessons ); ?></li>
                        <?php endif; ?>
                    </ul>
                <?php endif; ?>
                <ul class="courses-box-footer d-flex align-items-center justify-content-between">
                    <li>
                        <div class="author">
                            <div class="d-flex align-items-center justify-content-center">
                                <?php echo printf($course->get_instructor()->get_profile_picture()); ?>
                                <span><?php printf($course->get_instructor_html()); ?></span>
                            </div>
                        </div>
                    </li>
                    <li>
                        <?php learn_press_courses_loop_item_price(); ?>
                    </li>
                </ul>
            </div>
        </div>

        <div class="d-none">
            <?php do_action( 'learn-press/after-courses-loop-item' ); ?>
        </div>
    </div>
<?php else: ?>
    <div id="post-<?php the_ID(); ?>" class="col-lg-6 col-md-12 profile-page-extra-content-remove">
        <?php do_action( 'learn-press/before-courses-loop-item' ); ?>

        <div class="single-oet-courses-box">
            <div class="row m-0">
                <div class="col-lg-4 col-md-4 p-0">
                    <div class="image" style="background-image:url(<?php the_post_thumbnail_url('guto_banner_course'); ?>);">
                        <img src="<?php the_post_thumbnail_url('guto_banner_course'); ?>" alt="<?php the_post_thumbnail_caption(); ?>">
                        <a href="<?php the_permalink(); ?>" class="link-btn"></a>
                    </div>
                </div>

                <div class="col-lg-8 col-md-8 p-0">
                    <div class="content">
                        <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                        <?php if($course_students != '' || $course_page_lessons != ''): ?>
                            <ul class="courses-box-list d-flex align-items-center justify-content-between">
                                <?php if($course_students != ''): ?>
                                    <li><i class='bx bx-book'></i> <?php echo esc_html($course->get_curriculum_items( 'lp_lesson' )) ? count( $course->get_curriculum_items( 'lp_lesson' ) ) : 0; ?> <?php echo esc_html( $course_students  ); ?></li>
                                <?php endif; ?>

                                <?php if($course_page_lessons != ''): ?>
                                    <?php $user_count = $course->get_users_enrolled() ? $course->get_users_enrolled() : 0; ?>
                                    <li><i class='bx bx-group'></i> <?php echo esc_html( $user_count ); ?>  <?php echo esc_html( $course_page_lessons ); ?></li>
                                <?php endif; ?>
                            </ul>
                        <?php endif; ?>
                        <ul class="courses-box-footer d-flex align-items-center justify-content-between">
                            <li>
                                <div class="author">
                                    <div class="d-flex align-items-center justify-content-center">
                                        <?php printf($course->get_instructor()->get_profile_picture()); ?>
                                        <span><?php printf($course->get_instructor_html()); ?></span>
                                    </div>
                                </div>
                            </li>
                            <li>
                                <?php learn_press_courses_loop_item_price(); ?>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>

        <div class="d-none">
            <?php do_action( 'learn-press/after-courses-loop-item' ); ?>
        </div>
    </div>
<?php endif;
