<?php
/**
 * Template for displaying course content within the loop.
 *
 * This template can be overridden by copying it to guto/learnpress/content-single-course.php
 *
 * @author  EnvyTheme
 * @package LearnPress/Templates
 * @version 4.0.0
 */
$course         = LP()->global['course'];
$user           = LP_Global::user();
$course_id      = get_the_ID();
$user_id        = get_current_user_id();

$single_course_duration         = guto_lite_option( 'single_course_duration' );
$price_label                    = guto_lite_option( 'single_course_price_label' );
$instructor_label               = guto_lite_option( 'single_course_instructor_label' );
$single_course_lessons          = guto_lite_option( 'single_course_lessons' );
$single_course_access           = guto_lite_option( 'single_course_access' );
$buy_course_title               = guto_lite_option( 'single_buy_now' );

if ( defined( 'FW' ) ) {
    $preview_title          = fw_get_db_post_option( get_the_ID(), 'single_course_preview_title' );
    $single_video_link      = fw_get_db_post_option( get_the_ID(), 'single_video_link' );
    $single_duration        = fw_get_db_post_option( get_the_ID(), 'single_duration' );
    $single_access          = fw_get_db_post_option( get_the_ID(), 'single_access' );
}else {
    $preview_title      = esc_html__('Course Preview', 'guto-lite');
    $single_video_link  = esc_html__('#', 'guto-lite');
    $single_duration    = esc_html__('7 weeks', 'guto-lite');
    $single_access      = esc_html__('Lifetime', 'guto-lite');
}

get_template_part( 'template-parts/header/content', 'course-header' );

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );

if( $guto_lite_current_demo == 'motivational-speaker' ) :
    $guto_courses_details_area = 'ms-courses-details-area';
    $guto_courses_details_desc = 'ms-courses-details-desc';
    $guto_courses_details_info = 'ms-courses-details-info';
    $guto_courses_default_btn = 'ms-default-btn';
elseif( $guto_lite_current_demo == 'life-coaching' ) :
    $guto_courses_details_area = 'lc-courses-details-area';
    $guto_courses_details_desc = 'lc-courses-details-desc';
    $guto_courses_details_info = 'lc-courses-details-info';
    $guto_courses_default_btn = 'lc-default-btn';
endif;

if( $guto_lite_current_demo == 'motivational-speaker' || $guto_lite_current_demo == 'life-coaching' ) : ?>
    <div class="<?php echo esc_attr( $guto_courses_details_area ); ?> ptb-100">
        <div class="container-lg">
            <div class="row">
                <div class="col-lg-8 col-md-12">
                    <div class="<?php echo esc_attr( $guto_courses_details_desc ); ?>">
                        <?php
                        /**
                         * Prevent loading this file directly
                         */
                        defined( 'ABSPATH' ) || exit();

                        if ( post_password_required() ) {
                            echo get_the_password_form();
                            return;
                        }
                        ?>
                        <div id="learn-press-course" class="course-summary">
                            <?php
                            /**
                             * @since 3.0.0
                             *
                             * @see learn_press_single_course_summary()
                             */
                            LP()->template( 'course' )->user_progress();
                            do_action( 'learn-press/single-course-summary' );
                            ?>
                        </div>
                    </div>
                </div>
                <div class="col-lg-4 col-md-12">
                    <div class="<?php echo esc_attr( $guto_courses_details_info ); ?>">
                        <?php if(has_post_thumbnail()) { ?>
                            <div class="image">
                                <img src="<?php the_post_thumbnail_url('full') ?>" alt="<?php the_title_attribute(); ?>">
                                <?php if($single_video_link): ?>
                                    <a href="<?php echo esc_url($single_video_link); ?>" class="link-btn popup-youtube"></a>
                                <?php endif; ?>
                                <?php if($preview_title): ?>
                                    <div class="content">
                                        <i class='bx bx-play'></i>
                                        <span><?php echo esc_html($preview_title); ?></span>
                                    </div>
                                <?php endif; ?>
                            </div>
                        <?php } ?>

                        <ul class="info">
                            <li class="price">
                                <div class="d-flex justify-content-between align-items-center">
                                    <span><i class='bx bx-purchase-tag'></i> <?php echo esc_html($price_label); ?></span>
                                    <?php learn_press_courses_loop_item_price(); ?>
                                </div>
                            </li>

                            <li>
                                <div class="d-flex justify-content-between align-items-center">
                                    <span><i class='bx bxs-user'></i> <?php echo esc_html($instructor_label); ?></span>
                                    <?php if(get_the_author() == ''): ?>
                                    <?php
                                    $blogusers = get_users( array( 'fields' => array( 'display_name' )) );
                                    // Array of stdClass objects.
                                    foreach ( $blogusers as $user ) {
                                        echo '<span>' . esc_html( $user->display_name ) . '</span>';
                                    } ?>
                                    <?php else: ?>
                                        <?php the_author(); ?>
                                    <?php endif; ?>
                                </div>
                            </li>

                            <?php if($single_duration): ?>
                                <li>
                                    <div class="d-flex justify-content-between align-items-center">
                                        <span><i class='bx bx-time-five'></i> <?php echo esc_html($single_course_duration); ?></span>
                                        <?php echo esc_html($single_duration); ?>
                                    </div>
                                </li>
                            <?php endif; ?>

                            <li>
                                <div class="d-flex justify-content-between align-items-center">
                                    <span><i class='bx bx-laptop'></i> <?php echo esc_html($single_course_lessons); ?></span>
                                    <?php echo wp_kses_post( $course->get_curriculum_items( 'lp_lesson' ) ? count( $course->get_curriculum_items( 'lp_lesson' ) ) : 0 ); ?>
                                </div>
                            </li>

                            <li>
                                <div class="d-flex justify-content-between align-items-center">
                                    <span><i class='bx bx-lock-open-alt'></i> <?php echo esc_html($single_course_access); ?></span>
                                    <?php echo esc_html($single_access); ?>
                                </div>
                            </li>
                        </ul>

                        <?php if ( ! isset( $course ) ) {
                            $course = learn_press_get_course();
                        }

                        $classes_purchase = 'purchase-course';
                        $classes_purchase .= ( LP()->checkout()->is_enable_guest_checkout() ) ? ' guest_checkout' : '';

                        $classes_purchase = apply_filters( 'lp/btn/purchase/classes', $classes_purchase );
                        ?>

                        <?php do_action( 'learn-press/before-purchase-form' ); ?>

                            <form name="purchase-course" class="<?php echo esc_attr( $classes_purchase ); ?>" method="post" enctype="multipart/form-data">

                                <?php do_action( 'learn-press/before-purchase-button' ); ?>

                                <input type="hidden" name="purchase-course" value="<?php echo esc_attr( $course->get_id() ); ?>"/>

                                <button class="<?php echo esc_attr( $guto_courses_default_btn ); ?> button-purchase-course">
                                    <?php echo esc_html( $buy_course_title ); ?>
                                </button><br/>

                                <?php do_action( 'learn-press/after-purchase-button' ); ?>

                            </form>

                        <?php do_action( 'learn-press/after-purchase-form' ); ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
<?php else: ?>
    <div class="oet-courses-details-area ptb-100">
        <div class="container">
            <div class="row">
                <div class="col-lg-8 col-md-12">
                    <div class="oet-courses-details-desc">
                        <?php
                        /**
                         * Prevent loading this file directly
                         */
                        defined( 'ABSPATH' ) || exit();

                        if ( post_password_required() ) {
                            echo get_the_password_form();
                            return;
                        }
                        ?>
                        <div id="learn-press-course" class="course-summary">
                            <?php
                            /**
                             * @since 3.0.0
                             *
                             * @see learn_press_single_course_summary()
                             */
                            LP()->template( 'course' )->user_progress();
                            do_action( 'learn-press/single-course-summary' );
                            ?>
                        </div>
                        <?php
                        ?>
                        <?php if ( comments_open() || get_comments_number() ) : comments_template(); endif; ?>
                    </div>
                </div>
                <div class="col-lg-4 col-md-12">
                    <div class="oet-courses-details-info">
                        <?php if(has_post_thumbnail()) { ?>
                            <div class="image">
                                <img src="<?php the_post_thumbnail_url('full') ?>" alt="<?php the_title_attribute(); ?>">
                                <?php if($single_video_link): ?>
                                    <a href="<?php echo esc_url($single_video_link); ?>" class="link-btn popup-youtube"></a>
                                <?php endif; ?>
                                <?php if($preview_title): ?>
                                    <div class="content">
                                        <i class='bx bx-play'></i>
                                        <span><?php echo esc_html($preview_title); ?></span>
                                    </div>
                                <?php endif; ?>
                            </div>
                        <?php } ?>

                        <ul class="info">
                            <?php if($price_label): ?>
                                <li class="price">
                                    <div class="d-flex justify-content-between align-items-center">
                                        <span><i class='bx bx-purchase-tag'></i> <?php echo esc_html($price_label); ?></span>
                                        <?php learn_press_courses_loop_item_price(); ?>
                                    </div>
                                </li>
                            <?php endif; ?>

                            <?php if($instructor_label): ?>
                                <li>
                                    <div class="d-flex justify-content-between align-items-center">
                                        <span><i class='bx bxs-user'></i> <?php echo esc_html($instructor_label); ?></span>
                                        <?php echo esc_html(get_the_author()); ?>
                                    </div>
                                </li>
                            <?php endif; ?>

                            <?php if($single_duration): ?>
                                <li>
                                    <div class="d-flex justify-content-between align-items-center">
                                        <span><i class='bx bx-time-five'></i> <?php echo esc_html($single_course_duration); ?></span>
                                        <?php echo esc_html($single_duration); ?>
                                    </div>
                                </li>
                            <?php endif; ?>

                            <?php if($single_course_lessons): ?>
                                <li>
                                    <div class="d-flex justify-content-between align-items-center">
                                        <span><i class='bx bx-laptop'></i> <?php echo esc_html($single_course_lessons); ?></span>
                                        <?php echo wp_kses_post( $course->get_curriculum_items( 'lp_lesson' ) ? count( $course->get_curriculum_items( 'lp_lesson' ) ) : 0 ); ?>
                                    </div>
                                </li>
                            <?php endif; ?>

                            <?php if($single_course_access): ?>
                                <li>
                                    <div class="d-flex justify-content-between align-items-center">
                                        <span><i class='bx bx-lock-open-alt'></i> <?php echo esc_html($single_course_access); ?></span>
                                        <?php echo esc_html($single_access); ?>
                                    </div>
                                </li>
                            <?php endif; ?>
                        </ul>


                        <?php if( $course->get_external_link() == '' ): ?>
                            <?php
                                    $course = LP_Global::course();
                                    $price_html = $course->get_price_html();
                                ?>
                                    <?php if( learn_press_is_enrolled_course( $course_id, $user_id ) == false ): ?>
                                        <?php do_action( 'learn-press/before-enroll-form' ); ?>
                                            <form name="purchase-course" class="purchase-course" method="post" enctype="multipart/form-data">

                                                <?php do_action( 'learn-press/before-enroll-button' ); ?>

                                                <input type="hidden" name="purchase-course" value="<?php echo esc_attr( $course->get_id() ); ?>"/>
                                                <input type="hidden" name="purchase-course-nonce"
                                                    value="<?php echo esc_attr( LP_Nonce_Helper::create_course( 'enroll' ) ); ?>"/>

                                                <?php if(  $buy_course_title  != '' ): ?>
                                                    <button class="oet-default-btn lp-button button button-purchase-course">
                                                        <?php echo esc_html( $buy_course_title ); ?>
                                                    </button>
                                                <?php endif; ?>

                                                <?php do_action( 'learn-press/after-enroll-button' ); ?>

                                            </form>
                                        <?php do_action( 'learn-press/after-enroll-form' ); ?>
                                    <?php endif; ?>

                            <?php else: ?>
                                <form name="course-external-link" class="course-external-link form-button lp-form" method="post">
                                    <input type="hidden" name="lp-ajax" value="external-link">
                                    <input type="hidden" name="id" value="<?php echo esc_attr($course->get_id()); ?>">
                                    <input type="hidden" name="nonce" value="<?php echo wp_create_nonce( 'external-link-' . $course->get_external_link() ); ?>">
                                    <?php if(  $buy_course_title  != '' ): ?>
                                        <button type="submit" class="oet-default-btn lp-button button"><?php echo esc_html( $buy_course_title ); ?></button>
                                    <?php endif; ?>
                                </form>
                            <?php endif; ?>
                    </div>
                    <div class="single-course-sidebar">
                        <?php if ( is_active_sidebar( 'course-sidebar' ) ): ?>
                            <?php dynamic_sidebar('course-sidebar'); ?>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
<?php endif;

    $show_free_section = guto_lite_option('show_free_section');
    $show_contact_section = guto_lite_option('show_contact_section');
    $show_newsletter_section = guto_lite_option('show_newsletter_section');
    $free_section_image = guto_lite_option('free_section_image');
    $free_section_bg_image = guto_lite_option('free_section_bg_image');
    $free_section_subtitle = guto_lite_option('free_section_subtitle');
    $free_section_title = guto_lite_option('free_section_title');
    $free_section_desc = guto_lite_option('free_section_desc');
    $free_section_btn_text = guto_lite_option('free_section_btn_text');
    $free_section_btn_link = guto_lite_option('free_section_btn_link');
    $free_section_btn_icon = guto_lite_option('free_section_btn_icon');
    $contact_items = guto_lite_option('contact_section_items');
    $contact_text = guto_lite_option('contact_text');
    $contact_image = guto_lite_option('contact_image');
    $newsletter_section_subtitle = guto_lite_option('newsletter_section_subtitle');
    $newsletter_section_title = guto_lite_option('newsletter_section_title');
    $newsletter_section_desc = guto_lite_option('newsletter_section_desc');
    $newsletter_section_btn_text = guto_lite_option('newsletter_section_btn_text');
    $newsletter_section_btn_icon = guto_lite_option('newsletter_section_btn_icon');
    $newsletter_section_action_url = guto_lite_option('newsletter_section_action_url');

if( $guto_lite_current_demo == 'motivational-speaker' ) : 

    if( $show_free_section ) : ?>
        <!-- Start Free Trial Area -->
        <div class="ms-free-trial-area pb-100">
            <div class="container-lg">
                <div class="row align-items-center">
                    <div class="col-lg-5 col-md-12">
                        <div class="ms-free-trial-image">
                            <img src="<?php echo esc_html($free_section_image); ?>" alt="woman">
                        </div>
                    </div>
                    <div class="col-lg-7 col-md-12">
                        <div class="ms-free-trial-content">
                            <span class="sub-title"><?php echo esc_html($free_section_subtitle); ?></span>
                            <h2><?php echo esc_html($free_section_title); ?></h2>
                            <p><?php echo esc_html($free_section_desc); ?></p>
                            <?php if(!$free_section_btn_text == '') : ?>
                                <a href="<?php echo esc_url($free_section_btn_link); ?>" class="ms-default-btn"><i class='<?php echo esc_html($free_section_btn_icon); ?>'></i> <?php echo esc_html($free_section_btn_text); ?></a>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- End Free Trial Area -->
    <?php endif; ?>
    
    <?php if( $show_contact_section ) : ?>
    <!-- Start Contact Info Area -->
    <div class="ms-contact-info-area pt-100 pb-70">
        <div class="container-lg">
            <div class="row align-items-center justify-content-center">
                <?php if ($contact_items) { ?>
                    <?php if (is_array($contact_items) && !empty($contact_items)): ?>
                        <?php foreach ($contact_items as $index => $item): ?>
                            <div class="col-lg-4 col-sm-6 col-md-4">
                                <div class="ms-contact-info-box">
                                    <div class="d-table">
                                        <div class="d-table-cell">
                                            <div class="icon">
                                                <img src="<?php echo esc_url($item['contact_image']) ?>" alt="icon">
                                            </div>
                                            <h3><?php echo wp_kses_post($item['contact_text']) ?></h3>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    <?php endif; ?>
                <?php } ?>
            </div>
        </div>
    </div>
    <!-- End Contact Info Area -->
    <?php endif; ?>
    
    <?php if( $show_newsletter_section ) : ?>
    <!-- Start Subscribe Area -->
    <div class="ms-subscribe-area pb-100">
        <div class="container-lg">
            <div class="ms-subscribe-content">
                <span class="sub-title"><?php echo esc_html($newsletter_section_subtitle); ?></span>
                <h2><?php echo esc_html($newsletter_section_title); ?></h2>
                <p><?php echo esc_html($newsletter_section_desc); ?></p>
                <form class="mailchimp newsletter-form">
                    <input type="email" class="input-newsletter" placeholder="<?php echo esc_attr__('Enter your email address', 'guto-lite'); ?>" name="EMAIL">
                    <button type="submit" class="ms-default-btn"><i class='<?php echo esc_html($newsletter_section_btn_icon); ?>'></i> <?php echo esc_html($newsletter_section_btn_text); ?></button>
                    <p class="mchimp-errmessage" style="display: none;"></p>
                    <p class="mchimp-sucmessage" style="display: none;"></p>
                </form>
            </div>
        </div>
    </div>
    <!-- End Subscribe Area -->
    <?php endif; ?>
    
<?php endif;

if( $guto_lite_current_demo == 'life-coaching' ) : ?>
    
    <?php if( $show_free_section ) : ?>
    <!-- Start Free Trial Area -->
    <div class="lc-free-trial-area ptb-100" style="background-image: url(<?php echo esc_url( $free_section_bg_image ); ?> );">
        <div class="container-lg">
            <div class="row align-items-center">
                <div class="col-lg-6 col-md-12">
                    <div class="lc-free-trial-content">
                        <span class="sub-title"><?php echo esc_html($free_section_subtitle); ?></span>
                        <h2><?php echo esc_html($free_section_title); ?></h2>
                        <p><?php echo esc_html($free_section_desc); ?></p>
                        <?php if(!$free_section_btn_text == '') : ?>
                            <a href="<?php echo esc_url($free_section_btn_link); ?>" class="lc-default-btn"><i class='<?php echo esc_html($free_section_btn_icon); ?>'></i> <?php echo esc_html($free_section_btn_text); ?></a>
                        <?php endif; ?>
                    </div>
                </div>
                <div class="col-lg-6 col-md-12">
                    <div class="lc-free-trial-image">
                        <img src="<?php echo esc_html($free_section_image); ?>" alt="woman">
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- End Free Trial Area -->
    <?php endif; ?>
    
    <?php if( $show_contact_section ) : ?>
    <!-- Start Contact Info Area -->
    <div class="lc-contact-info-area pt-100 pb-70">
        <div class="container-lg">
            <div class="row align-items-center justify-content-center">
                <?php if ($contact_items) { ?>
                    <?php if (is_array($contact_items) && !empty($contact_items)): ?>
                        <?php foreach ($contact_items as $index => $item): ?>
                            <div class="col-lg-4 col-sm-6 col-md-4">
                                <div class="lc-contact-info-box">
                                    <div class="d-table">
                                        <div class="d-table-cell">
                                            <div class="icon">
                                                <img src="<?php echo esc_url($item['contact_image']) ?>" alt="icon">
                                            </div>
                                            <h3><?php echo wp_kses_post($item['contact_text']) ?></h3>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    <?php endif; ?>
                <?php } ?>
            </div>
        </div>
    </div>
    <!-- End Contact Info Area -->
    <?php endif; ?>
    
    <?php if( $show_newsletter_section ) : ?>
    <!-- Start Subscribe Area -->
    <div class="lc-subscribe-area pb-100">
        <div class="container-lg">
            <div class="lc-subscribe-content">
                <span class="sub-title"><?php echo esc_html($newsletter_section_subtitle); ?></span>
                <h2><?php echo esc_html($newsletter_section_title); ?></h2>
                <p><?php echo esc_html($newsletter_section_desc); ?></p>
                <form class="mailchimp newsletter-form">
                    <input type="email" class="input-newsletter" placeholder="<?php echo esc_attr__('Enter your email address', 'guto-lite'); ?>" name="EMAIL">
                    <button type="submit" class="lc-default-btn"><i class='<?php echo esc_html($newsletter_section_btn_icon); ?>'></i> <?php echo esc_html($newsletter_section_btn_text); ?></button>
                    <p class="mchimp-errmessage" style="display: none;"></p>
                    <p class="mchimp-sucmessage" style="display: none;"></p>
                </form>
            </div>
        </div>
    </div>
    <!-- End Subscribe Area -->
    <?php endif; ?>
    
<?php endif; ?>

<script>
    ;(function($){
        "use strict";
        $(document).ready(function () {
            // MAILCHIMP
            if ($(".mailchimp").length > 0) {
                $(".mailchimp").ajaxChimp({
                    callback: mailchimpCallback,
                    url: "<?php echo esc_js($newsletter_section_action_url) ?>"
                });
            }
            $(".memail").on("focus", function () {
                $(".mchimp-errmessage").fadeOut();
                $(".mchimp-sucmessage").fadeOut();
            });
            $(".memail").on("keydown", function () {
                $(".mchimp-errmessage").fadeOut();
                $(".mchimp-sucmessage").fadeOut();
            });
            $(".memail").on("click", function () {
                $(".memail").val("");
            });

            function mailchimpCallback(resp) {
                if (resp.result === "success") {
                    $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                    $(".mchimp-sucmessage").fadeOut(500);
                } else if (resp.result === "error") {
                    $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                }
            }
        });
    })(jQuery)
</script>
