<?php
/**
 * Template for displaying global login form.
 *
 * This template can be overridden by copying it to guto-lite/learnpress/global/form-register.php.
 *
 * @author   ThimPress
 * @package  Learnpress/Templates
 * @version  4.0.0
 */

defined( 'ABSPATH' ) || exit();

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );

if( $guto_lite_current_demo == 'motivational-speaker' ) :
    $guto_register_form = 'ms-login-form';
elseif( $guto_lite_current_demo == 'life-coaching' ) :
    $guto_register_form = 'lc-login-form';
endif;

if( $guto_lite_current_demo == 'motivational-speaker' || $guto_lite_current_demo == 'life-coaching' ) : ?>
<div class="col-lg-6 col-md-12">
    <div class="<?php echo esc_attr( $guto_register_form ); ?> learn-press-form">

        <h2><?php echo esc_html_x( 'Register', 'register-heading', 'guto-lite' ); ?></h2>

        <?php do_action( 'learn-press/before-form-register' ); ?>

        <form name="learn-press-register" method="post" action="">

            <?php do_action( 'learn-press/before-form-register-fields' ); ?>

            <div class="form-group">
                <label for="reg_email"><?php esc_html_e( 'Email address', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
                <input id ="reg_email" name="reg_email" class="form-control" type="text" placeholder="<?php esc_attr_e( 'Email', 'guto-lite' ); ?>" autocomplete="email" value="<?php echo ( ! empty( $_POST['reg_email'] ) ) ? esc_attr( wp_unslash( $_POST['reg_email'] ) ) : ''; ?>">
            </div>
            <div class="form-group">
                <label for="reg_username"><?php esc_html_e( 'Username', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
                <input id ="reg_username" name="reg_username" class="form-control" type="text" placeholder="<?php esc_attr_e( 'Username', 'guto-lite' ); ?>" autocomplete="username" value="<?php echo ( ! empty( $_POST['reg_username'] ) ) ? esc_attr( wp_unslash( $_POST['reg_username'] ) ) : ''; ?>">
            </div>
            <div class="form-group">
                <label for="reg_password"><?php esc_html_e( 'Password', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
                <input id ="reg_password" name="reg_password" class="form-control" type="password" placeholder="<?php esc_attr_e( 'Password', 'guto-lite' ); ?>" autocomplete="new-password">
            </div>

            <?php do_action( 'learn-press/after-form-register-fields' ); ?>

            <?php do_action( 'register_form' ); ?>

            <p class="description"><?php esc_html_e( 'The password should be at least eight characters long. To make it stronger, use upper and lower case letters, numbers, and symbols like ! " ? $ % ^ &', 'guto-lite' ); ?></p>

            <p>
                <?php wp_nonce_field( 'learn-press-register', 'learn-press-register-nonce' ); ?>
                <button type="submit"><?php esc_html_e( 'Register', 'guto-lite' ); ?></button>
            </p>

        </form>

        <?php do_action( 'learn-press/after-form-register' ); ?>

    </div>
</div>
<?php else : ?>
<div class="col-lg-6">
    <div class="learn-press-form-register learn-press-form">

        <h3><?php echo esc_html_x( 'Register', 'register-heading', 'guto-lite' ); ?></h3>

        <?php do_action( 'learn-press/before-form-register' ); ?>

        <form name="learn-press-register" method="post" action="">

            <ul class="form-fields">

                <?php do_action( 'learn-press/before-form-register-fields' ); ?>

                <li class="form-field">
                    <label for="reg_email"><?php esc_html_e( 'Email address', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
                    <input id ="reg_email" name="reg_email" type="text" placeholder="<?php esc_attr_e( 'Email', 'guto-lite' ); ?>" autocomplete="email" value="<?php echo ( ! empty( $_POST['reg_email'] ) ) ? esc_attr( wp_unslash( $_POST['reg_email'] ) ) : ''; ?>">
                </li>
                <li class="form-field">
                    <label for="reg_username"><?php esc_html_e( 'Username', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
                    <input id ="reg_username" name="reg_username" type="text" placeholder="<?php esc_attr_e( 'Username', 'guto-lite' ); ?>" autocomplete="username" value="<?php echo ( ! empty( $_POST['reg_username'] ) ) ? esc_attr( wp_unslash( $_POST['reg_username'] ) ) : ''; ?>">
                </li>
                <li class="form-field">
                    <label for="reg_password"><?php esc_html_e( 'Password', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
                    <input id ="reg_password" name="reg_password" type="password" placeholder="<?php esc_attr_e( 'Password', 'guto-lite' ); ?>" autocomplete="new-password">
                </li>

                <?php do_action( 'learn-press/after-form-register-fields' ); ?>
            </ul>

            <?php do_action( 'register_form' ); ?>

            <p>
                <?php wp_nonce_field( 'learn-press-register', 'learn-press-register-nonce' ); ?>
                <button type="submit"><?php esc_html_e( 'Register', 'guto-lite' ); ?></button>
            </p>

        </form>

        <?php do_action( 'learn-press/after-form-register' ); ?>

    </div>
</div>
<?php endif;
