<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to guto-lite/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.4.0
 */

defined( 'ABSPATH' ) || exit;

get_header( 'shop' );

remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );

do_action( 'woocommerce_before_main_content' );

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );
$is_pagi_loadmore = guto_lite_option( 'is_pagi_load' );
$rb_loadmore_title = guto_lite_option( 'rb_loadmore_title' );
$rb_product_slice = guto_lite_option( 'rb_product_slice' );
$rb_slice_per_load = guto_lite_option( 'rb_slice_per_load' );

$shop_style = guto_lite_option( 'shop_style' );

if( $shop_style == '' || $shop_style == 'style-1' || $shop_style == 'style-2' || $shop_style == 'style-ls') :
  $shop_style_class = 'products-area ptb-100';
  $shop_style_col = 'col-lg-8 col-md-12';
  $shop_style_container = 'container';
endif;

if( $guto_lite_current_demo == 'life-coaching' ) :
  $shop_style_class = 'lc-products-area ptb-100';
  $shop_style_col = 'col-lg-4 col-md-6 col-sm-6';
  $shop_style_container = 'container-lg';
endif;

get_template_part( 'template-parts/header/content', 'shop-header' );

$shop_sidebar       = guto_lite_option( 'shop_sidebar' );

?>

<div class="<?php echo esc_attr( $shop_style_class ); ?>">
    <div class="<?php echo esc_attr( $shop_style_container ); ?>">
        <div class="row justify-content-center">
            <?php if ( is_active_sidebar( 'shop' ) ): ?>
                 <?php if ( isset( $_GET['shop-sidebar'] ) ): ?>
                    <?php  $guto_lite_shop_cat_sidebar = sanitize_text_field(wp_unslash($_GET['shop-sidebar'])); ?>
                    <?php if ( $guto_lite_shop_cat_sidebar == 'none' ): ?>
                        <div class="col-lg-12 col-md-12">
                    <?php elseif ( $guto_lite_shop_cat_sidebar == 'left' ): ?>
                        <?php do_action( 'woocommerce_sidebar' ); ?>
                         <div class="<?php echo esc_attr( $shop_style_col ); ?>">
                    <?php elseif ( $guto_lite_shop_cat_sidebar == 'right' ): ?>
                         <div class="<?php echo esc_attr( $shop_style_col ); ?>">
                    <?php endif; ?>
                <?php else: ?>
                    <?php if( $shop_sidebar == 'left' ): ?>
                        <?php do_action( 'woocommerce_sidebar' ); ?>
                         <div class="<?php echo esc_attr( $shop_style_col ); ?>">
                    <?php elseif ( $shop_sidebar == 'right' ): ?>
                         <div class="<?php echo esc_attr( $shop_style_col ); ?>">
                    <?php else: ?>
                        <div class="col-lg-12 col-md-12">
                    <?php endif; ?>
                <?php endif; ?>
            <?php else: ?>
                <div class="col-lg-12 col-md-12">
            <?php endif; ?>
                <?php
                if ( woocommerce_product_loop() ) {

                    /**
                     * Hook: woocommerce_before_shop_loop.
                     *
                     * @hooked woocommerce_output_all_notices - 10
                     * @hooked woocommerce_result_count - 20
                     * @hooked woocommerce_catalog_ordering - 30
                     */

                    ?>
                    <div class="woocommerce-topbar">
                        <?php do_action( 'woocommerce_before_shop_loop' ); ?>
                    </div>
                    <?Php

                    woocommerce_product_loop_start();

                    if ( wc_get_loop_prop( 'total' ) ) {
                        while ( have_posts() ) {
                            the_post();

                            /**
                             * Hook: woocommerce_shop_loop.
                             *
                             * @hooked WC_Structured_Data::generate_product_data() - 10
                             */
                            do_action( 'woocommerce_shop_loop' );

                            wc_get_template_part( 'content', 'product' );
                        }
                    }

                    woocommerce_product_loop_end();

                    if ( $guto_lite_current_demo == 'recipe-blog'):
                        if($is_pagi_loadmore == 'rb-load' && wc_get_loop_prop( 'total' ) >= $rb_product_slice) : ?>
                            <div class="rb-shop-btn">
                                <a href="<?php echo esc_url( get_home_url( ).'/shop/' ); ?>" id="loadmore" class="rb-default-btn"><?php echo esc_html( $rb_loadmore_title ); ?></a>
                            </div>
                        <?php else :
                            do_action( 'woocommerce_after_shop_loop' );
                        endif ?>

                        <script>
                            ;(function($){
                                "use strict";
                                $(document).ready(function () {
                                    // Load More
                                    $(".event-boxed")
                                    .slice(0, <?php echo esc_attr($rb_product_slice); ?>)
                                    .show();
                                    $("#loadmore").on("click", function(e) {
                                        e.preventDefault();
                                        $(
                                            ".event-boxed:hidden"
                                        )
                                            .slice(0, <?php echo esc_attr($rb_slice_per_load); ?>)
                                            .slideDown();
                                        if (
                                            $(
                                                ".event-boxed:hidden"
                                            ).length == 0
                                        ) {
                                            $("#loadmore").fadeOut("slow");
                                        }
                                        $("html,body").animate(
                                            {
                                                scrollTop: $(this).offset().top
                                            },
                                            1500
                                        );
                                    });
                                });
                            })(jQuery)
                        </script>

                    <?php else :
                        /**
                         * Hook: woocommerce_after_shop_loop.
                         *
                         * @hooked woocommerce_pagination - 10
                         */
                        do_action( 'woocommerce_after_shop_loop' );
                    endif;
                } else {
                    /**
                     * Hook: woocommerce_no_products_found.
                     *
                     * @hooked wc_no_products_found - 10
                     */
                    do_action( 'woocommerce_no_products_found' );
                }
                ?>
            </div> <!-- end clo-8 -->

            <?php
            if ( isset( $_GET['shop-sidebar'] ) ):
                if ( $guto_lite_shop_cat_sidebar == 'right' ) :
                    do_action( 'woocommerce_sidebar' );
                endif;
            else:
                if ( $shop_sidebar == 'right' ):
                    do_action( 'woocommerce_sidebar' );
                endif;
            endif;
            ?>
        </div>
            <?php
            /**
             * Hook: woocommerce_after_main_content.
             *
             * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
             */
            do_action( 'woocommerce_after_main_content' );

            /**
             * Hook: woocommerce_sidebar.
             *
             * @hooked woocommerce_get_sidebar - 10
             */

            if ( $guto_lite_current_demo == 'online-health-coach'):
                $is_ohc_cta  = guto_lite_option('is_ohc_cta');
                $is_ohc_contact  = guto_lite_option('is_ohc_contact');

                if( $is_ohc_cta ):
                    get_template_part( 'template-parts/footer/footer','cta-ohc' );
                endif;

                if( $is_ohc_contact ):
                    get_template_part( 'template-parts/footer/footer','contact-info-ohc' );
                endif;
            endif;

            get_footer( 'shop' );

            ?>
        </div>
    </div>
</div>