<?php
/**
 * Checkout Form
 *
 * This template can be overridden by copying it to guto-lite/woocommerce/checkout/form-checkout.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

do_action( 'woocommerce_before_checkout_form', $checkout );

// If checkout registration is disabled and not logged in, the user cannot checkout.
if ( ! $checkout->is_registration_enabled() && $checkout->is_registration_required() && ! is_user_logged_in() ) {
	echo esc_html( apply_filters( 'woocommerce_checkout_must_be_logged_in_message', __( 'You must be logged in to checkout.', 'guto-lite' ) ) );
	return;
}

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );

$checkout_style = guto_lite_option( 'checkout_style' );

if( $checkout_style == 'style-1' ) : ?>

    <div class="checkout-area">
        <form name="checkout" method="post" class="checkout woocommerce-checkout" action="<?php echo esc_url( wc_get_checkout_url() ); ?>" enctype="multipart/form-data">

            <?php if ( $checkout->get_checkout_fields() ) : ?>

                <?php do_action( 'woocommerce_checkout_before_customer_details' ); ?>

                <div class="col2-set " id="customer_details">
                    <div class="row">
                        <div class="col-lg-6">
                            <?php do_action( 'woocommerce_checkout_billing' ); ?>
                            <?php do_action( 'woocommerce_checkout_shipping' ); ?>

                        </div>

                        <div class="col-lg-6">
                            <div class="order-details">
                                <h3 class="title"><?php esc_html_e( 'Your order', 'guto-lite' ); ?></h3>

                                <?php do_action( 'woocommerce_checkout_before_order_review' ); ?>

                                <div id="order_review" class="woocommerce-checkout-review-order">
                                    <?php do_action( 'woocommerce_checkout_order_review' ); ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <?php do_action( 'woocommerce_checkout_after_customer_details' ); ?>

            <?php endif; ?>

            <?php do_action( 'woocommerce_checkout_before_order_review_heading' ); ?>



            <?php do_action( 'woocommerce_checkout_after_order_review' ); ?>

        </form>
    </div>

<?php elseif( $checkout_style == 'style-2' ) : ?>

    <form name="checkout" method="post" class="checkout woocommerce-checkout" action="<?php echo esc_url( wc_get_checkout_url() ); ?>" enctype="multipart/form-data">

        <?php if ( $checkout->get_checkout_fields() ) : ?>

            <?php do_action( 'woocommerce_checkout_before_customer_details' ); ?>

            <div class="col2-set " id="customer_details">
                <div class="row">
                    <div class="col-lg-6">
                        <?php do_action( 'woocommerce_checkout_billing' ); ?>
                        <?php do_action( 'woocommerce_checkout_shipping' ); ?>

                    </div>

                    <div class="col-lg-6">
                         <div class="restaurant-order-details">
                            <h3 class="title"><?php esc_html_e( 'Your order', 'guto-lite' ); ?></h3>

                            <?php do_action( 'woocommerce_checkout_before_order_review' ); ?>

                            <div id="order_review" class="woocommerce-checkout-review-order">
                                <?php do_action( 'woocommerce_checkout_order_review' ); ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <?php do_action( 'woocommerce_checkout_after_customer_details' ); ?>

        <?php endif; ?>

        <?php do_action( 'woocommerce_checkout_before_order_review_heading' ); ?>



        <?php do_action( 'woocommerce_checkout_after_order_review' ); ?>

    </form>

<?php elseif( $checkout_style == 'style-ls' ) : ?>

    <div class="fls-checkout-area">
        <form name="checkout" method="post" class="checkout woocommerce-checkout" action="<?php echo esc_url( wc_get_checkout_url() ); ?>" enctype="multipart/form-data">

            <?php if ( $checkout->get_checkout_fields() ) : ?>

                <?php do_action( 'woocommerce_checkout_before_customer_details' ); ?>

                <div class="col2-set " id="customer_details">
                    <div class="row">
                        <div class="col-lg-8">
                            <?php do_action( 'woocommerce_checkout_billing' ); ?>
                            <?php do_action( 'woocommerce_checkout_shipping' ); ?>
                        </div>

                        <div class="col-lg-4">
                            <div class="checkout-item">

                                <?php do_action( 'woocommerce_checkout_before_order_review' ); ?>

                                <div id="order_review" class="woocommerce-checkout-review-order">
                                    <?php do_action( 'woocommerce_checkout_order_review' ); ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <?php do_action( 'woocommerce_checkout_after_customer_details' ); ?>

            <?php endif; ?>

            <?php do_action( 'woocommerce_checkout_before_order_review_heading' ); ?>



            <?php do_action( 'woocommerce_checkout_after_order_review' ); ?>

        </form>
    </div>

<?php elseif( $guto_lite_current_demo == 'life-coaching' ) : ?>

    <form name="checkout" method="post" class="checkout woocommerce-checkout" action="<?php echo esc_url( wc_get_checkout_url() ); ?>" enctype="multipart/form-data">

        <?php if ( $checkout->get_checkout_fields() ) : ?>

            <?php do_action( 'woocommerce_checkout_before_customer_details' ); ?>

            <div class="col2-set " id="customer_details">
                <div class="row">
                    <div class="col-lg-6">
                        <?php do_action( 'woocommerce_checkout_billing' ); ?>
                        <?php do_action( 'woocommerce_checkout_shipping' ); ?>

                    </div>

                    <div class="col-lg-6">
                         <div class="lc-order-details">
                            <h3 class="title"><?php esc_html_e( 'Your order', 'guto-lite' ); ?></h3>

                            <?php do_action( 'woocommerce_checkout_before_order_review' ); ?>

                            <div id="order_review" class="woocommerce-checkout-review-order">
                                <?php do_action( 'woocommerce_checkout_order_review' ); ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <?php do_action( 'woocommerce_checkout_after_customer_details' ); ?>

        <?php endif; ?>

        <?php do_action( 'woocommerce_checkout_before_order_review_heading' ); ?>



        <?php do_action( 'woocommerce_checkout_after_order_review' ); ?>

    </form>

<?php endif;

do_action( 'woocommerce_after_checkout_form', $checkout );