<?php
/**
 * Checkout Payment Section
 *
 * This template can be overridden by copying it to guto-lite/woocommerce/checkout/payment.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.5.3
 */

defined( 'ABSPATH' ) || exit;

if ( ! is_ajax() ) {
	do_action( 'woocommerce_review_order_before_payment' );
}

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );

$checkout_style = guto_lite_option( 'checkout_style' );

if( $checkout_style == 'style-1' ) : ?>

	<div id="payment" class="woocommerce-checkout-payment">
		<?php if ( WC()->cart->needs_payment() ) : ?>
			<ul class="wc_payment_methods payment_methods methods">
				<?php
				if ( ! empty( $available_gateways ) ) {
					foreach ( $available_gateways as $gateway ) {
						wc_get_template( 'checkout/payment-method.php', array( 'gateway' => $gateway ) );
					}
				} else {
					echo '<li class="woocommerce-notice woocommerce-notice--info woocommerce-info user-actions">' . apply_filters( 'woocommerce_no_available_payment_methods_message', WC()->customer->get_billing_country() ? esc_html__( 'Sorry, it seems that there are no available payment methods for your state. Please contact us if you require assistance or wish to make alternate arrangements.', 'guto-lite' ) : esc_html__( 'Please fill in your details above to see available payment methods.', 'guto-lite' ) ) . '</li>'; // @codingStandardsIgnoreLine
				}
				?>
			</ul>
		<?php endif; ?>
		<div class="form-row place-order">
			<noscript>
				<?php
				/* translators: $1 and $2 opening and closing emphasis tags respectively */
				printf( esc_html__( 'Since your browser does not support JavaScript, or it is disabled, please ensure you click the %1$sUpdate Totals%2$s button before placing your order. You may be charged more than the amount stated above if you fail to do so.', 'guto-lite' ), '<em>', '</em>' );
				?>
				<br/><button type="submit" class="button alt" name="woocommerce_checkout_update_totals" value="<?php esc_attr_e( 'Update totals', 'guto-lite' ); ?>"><?php esc_html_e( 'Update totals', 'guto-lite' ); ?></button>
			</noscript>

			<?php wc_get_template( 'checkout/terms.php' ); ?>

			<?php do_action( 'woocommerce_review_order_before_submit' ); ?>

			<?php echo apply_filters( 'woocommerce_order_button_html', '<button type="submit" class="default-btn " name="woocommerce_checkout_place_order" id="place_order" value="' . esc_attr( $order_button_text ) . '" data-value="' . esc_attr( $order_button_text ) . '">' . esc_html( $order_button_text ) . '</button>' ); // @codingStandardsIgnoreLine ?>

			<?php do_action( 'woocommerce_review_order_after_submit' ); ?>

			<?php wp_nonce_field( 'woocommerce-process_checkout', 'woocommerce-process-checkout-nonce' ); ?>
		</div>
	</div>
<?php

elseif( $checkout_style == 'style-2' ) : ?>

    <div id="payment" class="woocommerce-checkout-payment payment-box">
		<?php if ( WC()->cart->needs_payment() ) : ?>
			<div class="wc_payment_methods payment_methods methods payment-method">
				<?php
				if ( ! empty( $available_gateways ) ) {
					foreach ( $available_gateways as $gateway ) {
						wc_get_template( 'checkout/payment-method.php', array( 'gateway' => $gateway ) );
					}
				} else {
					echo '<p class="woocommerce-notice woocommerce-notice--info woocommerce-info user-actions">' . apply_filters( 'woocommerce_no_available_payment_methods_message', WC()->customer->get_billing_country() ? esc_html__( 'Sorry, it seems that there are no available payment methods for your state. Please contact us if you require assistance or wish to make alternate arrangements.', 'guto-lite' ) : esc_html__( 'Please fill in your details above to see available payment methods.', 'guto-lite' ) ) . '</p>'; // @codingStandardsIgnoreLine
				}
				?>
			</div>
		<?php endif; ?>
		<div class="form-row place-order">
			<noscript>
				<?php
				/* translators: $1 and $2 opening and closing emphasis tags respectively */
				printf( esc_html__( 'Since your browser does not support JavaScript, or it is disabled, please ensure you click the %1$sUpdate Totals%2$s button before placing your order. You may be charged more than the amount stated above if you fail to do so.', 'guto-lite' ), '<em>', '</em>' );
				?>
				<br/><button type="submit" class="" name="woocommerce_checkout_update_totals" value="<?php esc_attr_e( 'Update totals', 'guto-lite' ); ?>"><?php esc_html_e( 'Update totals', 'guto-lite' ); ?></button>
			</noscript>

			<?php wc_get_template( 'checkout/terms.php' ); ?>

			<?php do_action( 'woocommerce_review_order_before_submit' );
			$order_btn_icon = '<i class="bx bx-paper-plane"></i>'; ?>

			<?php echo apply_filters( 'woocommerce_order_button_html', '<button type="submit" class="default-btn" name="woocommerce_checkout_place_order" id="place_order" value="' . esc_attr( $order_button_text ) . '" data-value="' . esc_attr( $order_button_text ) . '">' . esc_html( $order_button_text ) . '</button>' ); // @codingStandardsIgnoreLine ?>

			<?php do_action( 'woocommerce_review_order_after_submit' ); ?>

			<?php wp_nonce_field( 'woocommerce-process_checkout', 'woocommerce-process-checkout-nonce' ); ?>
		</div>
	</div>

<?php elseif( $checkout_style == 'style-ls' ) : ?>

	<div id="payment" class="woocommerce-checkout-payment payment-box">
		<?php if ( WC()->cart->needs_payment() ) : ?>
			<div class="wc_payment_methods payment_methods methods payment-method">
				<?php
				if ( ! empty( $available_gateways ) ) {
					foreach ( $available_gateways as $gateway ) {
						wc_get_template( 'checkout/payment-method.php', array( 'gateway' => $gateway ) );
					}
				} else {
					echo '<p class="woocommerce-notice woocommerce-notice--info woocommerce-info user-actions">' . apply_filters( 'woocommerce_no_available_payment_methods_message', WC()->customer->get_billing_country() ? esc_html__( 'Sorry, it seems that there are no available payment methods for your state. Please contact us if you require assistance or wish to make alternate arrangements.', 'guto-lite' ) : esc_html__( 'Please fill in your details above to see available payment methods.', 'guto-lite' ) ) . '</p>'; // @codingStandardsIgnoreLine
				}
				?>
			</div>
		<?php endif; ?>
		<div class="form-row place-order">
			<noscript>
				<?php
				/* translators: $1 and $2 opening and closing emphasis tags respectively */
				printf( esc_html__( 'Since your browser does not support JavaScript, or it is disabled, please ensure you click the %1$sUpdate Totals%2$s button before placing your order. You may be charged more than the amount stated above if you fail to do so.', 'guto-lite' ), '<em>', '</em>' );
				?>
				<br/><button type="submit" class="" name="woocommerce_checkout_update_totals" value="<?php esc_attr_e( 'Update totals', 'guto-lite' ); ?>"><?php esc_html_e( 'Update totals', 'guto-lite' ); ?></button>
			</noscript>

			<?php wc_get_template( 'checkout/terms.php' ); ?>

			<?php do_action( 'woocommerce_review_order_before_submit' );
			$order_btn_icon = '<i class="bx bx-paper-plane"></i>'; ?>

			<?php echo apply_filters( 'woocommerce_order_button_html', '<button type="submit" class="default-btn fls-default-btn" name="woocommerce_checkout_place_order" id="place_order" value="' . esc_attr( $order_button_text ) . '" data-value="' . esc_attr( $order_button_text ) . '">' . esc_html( $order_button_text ) . '</button>' ); // @codingStandardsIgnoreLine ?>

			<?php do_action( 'woocommerce_review_order_after_submit' ); ?>

			<?php wp_nonce_field( 'woocommerce-process_checkout', 'woocommerce-process-checkout-nonce' ); ?>
		</div>
	</div>

<?php elseif( $guto_lite_current_demo == 'life-coaching' ) : ?>

	<div id="payment" class="woocommerce-checkout-payment payment-box">
		<?php if ( WC()->cart->needs_payment() ) : ?>
			<div class="wc_payment_methods payment_methods methods payment-method">
				<?php
				if ( ! empty( $available_gateways ) ) {
					foreach ( $available_gateways as $gateway ) {
						wc_get_template( 'checkout/payment-method.php', array( 'gateway' => $gateway ) );
					}
				} else {
					echo '<p class="woocommerce-notice woocommerce-notice--info woocommerce-info user-actions">' . apply_filters( 'woocommerce_no_available_payment_methods_message', WC()->customer->get_billing_country() ? esc_html__( 'Sorry, it seems that there are no available payment methods for your state. Please contact us if you require assistance or wish to make alternate arrangements.', 'guto-lite' ) : esc_html__( 'Please fill in your details above to see available payment methods.', 'guto-lite' ) ) . '</p>'; // @codingStandardsIgnoreLine
				}
				?>
			</div>
		<?php endif; ?>
		<div class="form-row place-order">
			<noscript>
				<?php
				/* translators: $1 and $2 opening and closing emphasis tags respectively */
				printf( esc_html__( 'Since your browser does not support JavaScript, or it is disabled, please ensure you click the %1$sUpdate Totals%2$s button before placing your order. You may be charged more than the amount stated above if you fail to do so.', 'guto-lite' ), '<em>', '</em>' );
				?>
				<br/><button type="submit" class="" name="woocommerce_checkout_update_totals" value="<?php esc_attr_e( 'Update totals', 'guto-lite' ); ?>"><?php esc_html_e( 'Update totals', 'guto-lite' ); ?></button>
			</noscript>

			<?php wc_get_template( 'checkout/terms.php' ); ?>

			<?php do_action( 'woocommerce_review_order_before_submit' );
			$order_btn_icon = '<i class="bx bx-paper-plane"></i>'; ?>

			<?php echo apply_filters( 'woocommerce_order_button_html', '<button type="submit" class="lc-default-btn" name="woocommerce_checkout_place_order" id="place_order" value="' . esc_attr( $order_button_text ) . '" data-value="' . esc_attr( $order_button_text ) . '">' . esc_html( $order_button_text ) . '</button>' ); // @codingStandardsIgnoreLine ?>

			<?php do_action( 'woocommerce_review_order_after_submit' ); ?>

			<?php wp_nonce_field( 'woocommerce-process_checkout', 'woocommerce-process-checkout-nonce' ); ?>
		</div>
	</div>

<?php endif;

if ( ! is_ajax() ) {
	do_action( 'woocommerce_review_order_after_payment' );
}
