<?php
/**
 * Login form
 *
 * This template can be overridden by copying it to guto-lite/woocommerce/global/form-login.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see         https://docs.woocommerce.com/document/template-structure/
 * @package     WooCommerce\Templates
 * @version     3.6.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( is_user_logged_in() ) {
	return;
}

$checkout_style = guto_lite_option( 'checkout_style' );

if( $checkout_style == '' || $checkout_style == 'style-1' ) : ?>

	<form class="woocommerce-form woocommerce-form-login login" method="post" <?php echo esc_html( ( $hidden ) ? 'style="display:none;"' : '' ); ?>>

	<?php do_action( 'woocommerce_login_form_start' ); ?>

	<?php printf( ( $message ) ? wpautop( wptexturize( $message ) ) : '' ); // @codingStandardsIgnoreLine ?>

	<p class="form-row form-row-first">
		<label for="username"><?php esc_html_e( 'Username or email', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
		<input type="text" class="input-text" name="username" id="username" autocomplete="username" />
	</p>
	<p class="form-row form-row-last">
		<label for="password"><?php esc_html_e( 'Password', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
		<input class="input-text" type="password" name="password" id="password" autocomplete="current-password" />
	</p>
	<div class="clear"></div>

	<?php do_action( 'woocommerce_login_form' ); ?>

	<p class="form-row">
		<label class="woocommerce-form__label woocommerce-form__label-for-checkbox woocommerce-form-login__rememberme">
			<input class="woocommerce-form__input woocommerce-form__input-checkbox" name="rememberme" type="checkbox" id="rememberme" value="forever" /> <span><?php esc_html_e( 'Remember me', 'guto-lite' ); ?></span>
		</label>
		<?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
		<input type="hidden" name="redirect" value="<?php echo esc_url( $redirect ); ?>" />
		<button type="submit" class="woocommerce-button button woocommerce-form-login__submit" name="login" value="<?php esc_attr_e( 'Login', 'guto-lite' ); ?>"><?php esc_html_e( 'Login', 'guto-lite' ); ?></button>
	</p>
	<p class="lost_password">
		<a href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php esc_html_e( 'Lost your password?', 'guto-lite' ); ?></a>
	</p>

	<div class="clear"></div>

	<?php do_action( 'woocommerce_login_form_end' ); ?>

    </form>

<?php elseif( $checkout_style == 'style-2' ) : ?>

		<form class="woocommerce-form woocommerce-form-login login" method="post" <?php echo esc_html( ( $hidden ) ? 'style="display:none;"' : '' ); ?>>

			<div class="restaurant-login-form">

		<?php do_action( 'woocommerce_login_form_start' ); ?>

		<?php printf( ( $message ) ? wpautop( wptexturize( $message ) ) : '' ); // @codingStandardsIgnoreLine ?>

		<div class="form-row form-row-first form-group">
			<label for="username"><?php esc_html_e( 'Username or email', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
			<input type="text" class="form-control" name="username" id="username" autocomplete="username" />
		</div>
		<div class="form-row form-row-last form-group">
			<label for="password"><?php esc_html_e( 'Password', 'guto-lite' ); ?>&nbsp;<span class="required">*</span></label>
			<input class="form-control" type="password" name="password" id="password" autocomplete="current-password" />
		</div>
		<div class="clear"></div>

		<?php do_action( 'woocommerce_login_form' ); ?>

		<div class="row align-items-center">

			<div class="col-lg-6 col-md-6 col-sm-6 remember-me-wrap wc-remember-me">

				<div class="form-row form-group">
					<label class="woocommerce-form__label woocommerce-form__label-for-checkbox woocommerce-form-login__rememberme">
						<input class="woocommerce-form__input woocommerce-form__input-checkbox" name="rememberme" type="checkbox" id="rememberme" value="forever" /> <span><?php esc_html_e( 'Remember me', 'guto-lite' ); ?></span>
					</label>

				</div>

		    </div>

		    <div class="col-lg-6 col-md-6 col-sm-6 lost-your-password-wrap">

		    	<a href="<?php echo esc_url( wp_lostpassword_url() ); ?>"><?php esc_html_e( 'Lost your password?', 'guto-lite' ); ?></a>

		    </div>

		</div>

		<?php wp_nonce_field( 'woocommerce-login', 'woocommerce-login-nonce' ); ?>
			<input type="hidden" name="redirect" value="<?php echo esc_url( $redirect ); ?>" />
			<button type="submit" class="woocommerce-button button woocommerce-form-login__submit" name="login" value="<?php esc_attr_e( 'Login', 'guto-lite' ); ?>"><?php esc_html_e( 'Login', 'guto-lite' ); ?></button>

		<div class="clear"></div>

		<?php do_action( 'woocommerce_login_form_end' ); ?>

		</div>

	    </form>

<?php endif;