<?php
/**
 * Pagination - Show numbered pagination for catalog pages
 *
 * This template can be overridden by copying it to guto-lite/woocommerce/loop/pagination.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.3.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$total   = isset( $total ) ? $total : wc_get_loop_prop( 'total_pages' );
$current = isset( $current ) ? $current : wc_get_loop_prop( 'current_page' );
$base    = isset( $base ) ? $base : esc_url_raw( str_replace( 999999999, '%#%', remove_query_arg( 'add-to-cart', get_pagenum_link( 999999999, false ) ) ) );
$format  = isset( $format ) ? $format : '';

if ( $total <= 1 ) {
	return;
}

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );
$shop_pagination_style = guto_lite_option( 'shop_pagination_style' ); ?>

<?php if( $guto_lite_current_demo == 'online-health-coach' ) : ?>
    <div class="ohc-pagination-area">
        <nav class="nav-links">
            <?php
                echo wp_kses_post(paginate_links( apply_filters( 'woocommerce_pagination_args', array(
                    'base'         => $base,
                    'format'       => $format,
                    'add_args'     => false,
                    'current'      => max( 1, $current ),
                    'total'        => $total,
                    'prev_text' => '<i class="bx bx-chevrons-left"></i>',
                    'next_text' => '<i class="bx bx-chevrons-right"></i>',
                    'end_size'     => 3,
                    'mid_size'     => 3,
                ) ) ) );
            ?>
        </nav>
    </div>
<?php elseif( $shop_pagination_style == 'style-2' ) : ?>
    <div class="os-pagination-area">
        <nav class="woocommerce-pagination">
            <?php
                echo wp_kses_post(paginate_links( apply_filters( 'woocommerce_pagination_args', array(
                    'base'         => $base,
                    'format'       => $format,
                    'add_args'     => false,
                    'current'      => max( 1, $current ),
                    'total'        => $total,
                    'prev_text' => '<i class="flaticon-left-arrow"></i>',
                    'next_text' => '<i class="flaticon-right-arrow-1"></i>',
                    'end_size'     => 3,
                    'mid_size'     => 3,
                ) ) ) );
            ?>
        </nav>
    </div>
<?php elseif( $shop_pagination_style == 'style-ls' ) : ?>
    <div class="fls-pagination-area">
        <nav class="woocommerce-pagination">
            <?php
                echo wp_kses_post(paginate_links( apply_filters( 'woocommerce_pagination_args', array(
                    'base'         => $base,
                    'format'       => $format,
                    'add_args'     => false,
                    'current'      => max( 1, $current ),
                    'total'        => $total,
                    'prev_text' => '<i class="bx bx-left-arrow-alt"></i>',
                    'next_text' => '<i class="bx bx-right-arrow-alt"></i>',
                    'end_size'     => 3,
                    'mid_size'     => 3,
                ) ) ) );
            ?>
        </nav>
    </div>
<?php elseif( $guto_lite_current_demo == 'life-coaching' ) : ?>
    <div class="col-lg-12 col-md-12 col-sm-12">
        <div class="lc-pagination-area">
            <div class="nav-links">
                <?php
                    echo wp_kses_post(paginate_links( apply_filters( 'woocommerce_pagination_args', array(
                        'base'         => $base,
                        'format'       => $format,
                        'add_args'     => false,
                        'current'      => max( 1, $current ),
                        'total'        => $total,
                        'prev_text' => '<i class="flaticon-left-arrow"></i>',
                        'next_text' => '<i class="flaticon-right-arrow-1"></i>',
                        'end_size'     => 3,
                        'mid_size'     => 3,
                    ) ) ) );
                ?>
            </div>
        </div>
    </div>
<?php elseif( $shop_pagination_style == 'style-1' || $shop_pagination_style == '' ) : ?>
    <div class="pagination-area">
        <nav class="woocommerce-pagination">
            <?php
                echo wp_kses_post(paginate_links( apply_filters( 'woocommerce_pagination_args', array(
                    'base'         => $base,
                    'format'       => $format,
                    'add_args'     => false,
                    'current'      => max( 1, $current ),
                    'total'        => $total,
                    'prev_text' => '<i class="bx bx-chevrons-left"></i>',
                    'next_text' => '<i class="bx bx-chevrons-right"></i>',
                    'end_size'     => 3,
                    'mid_size'     => 3,
                ) ) ) );
            ?>
        </nav>
    </div>
<?php endif;
