<?php
/**
 * Simple product add to cart
 *
 * This template can be overridden by copying it to guto-lite/woocommerce/single-product/add-to-cart/simple.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */

// phpcs:ignoreFile

defined( 'ABSPATH' ) || exit;

global $product;

if ( ! $product->is_purchasable() ) {
	return;
}

$shop_details_style    = guto_lite_option( 'shop_details_style' );

$guto_lite_current_demo = get_option( 'guto_lite_current_demo' );

echo wc_get_stock_html( $product );

if ( $product->is_in_stock() ) : ?>

	<?php do_action( 'woocommerce_before_add_to_cart_form' ); ?>

	<div class="products-add-to-cart">

		<form class="cart" action="<?php echo esc_url( apply_filters( 'woocommerce_add_to_cart_form_action', $product->get_permalink() ) ); ?>" method="post" enctype='multipart/form-data'>
			<?php do_action( 'woocommerce_before_add_to_cart_button' ); ?>

			<?php if($shop_details_style == 'style-ls'): ?>

				<div class="fls-counter">
					<?php
						do_action( 'woocommerce_before_add_to_cart_quantity' ); ?>
						<span><main><?php echo esc_html__('Quantities:', 'guto-lite'); ?></main>
						<?php

						woocommerce_quantity_input( array(
							'min_value'   => apply_filters( 'woocommerce_quantity_input_min', $product->get_min_purchase_quantity(), $product ),
							'max_value'   => apply_filters( 'woocommerce_quantity_input_max', $product->get_max_purchase_quantity(), $product ),
							'input_value' => isset( $_POST['quantity'] ) ? wc_stock_amount( wp_unslash( $_POST['quantity'] ) ) : $product->get_min_purchase_quantity(), // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
						) );

						do_action( 'woocommerce_after_add_to_cart_quantity' );?>
				</div>

			<?php else : ?>

				<?php
				do_action( 'woocommerce_before_add_to_cart_quantity' );

				woocommerce_quantity_input( array(
					'min_value'   => apply_filters( 'woocommerce_quantity_input_min', $product->get_min_purchase_quantity(), $product ),
					'max_value'   => apply_filters( 'woocommerce_quantity_input_max', $product->get_max_purchase_quantity(), $product ),
					'input_value' => isset( $_POST['quantity'] ) ? wc_stock_amount( wp_unslash( $_POST['quantity'] ) ) : $product->get_min_purchase_quantity(), // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
				) );

				do_action( 'woocommerce_after_add_to_cart_quantity' ); ?>

			<?php endif; 

			if( $shop_details_style == 'style-1' ) : ?>
				<button type="submit" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" class="default-btn default-btn-one"><i class="bx bxs-cart-add"></i><?php echo esc_html( $product->single_add_to_cart_text() ); ?></button>
			<?php elseif($shop_details_style == 'style-2'): ?>
				<button type="submit" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" class="default-btn"><i class="bx bxs-cart-add"></i><?php echo esc_html( $product->single_add_to_cart_text() ); ?></button>

			<?php elseif($guto_lite_current_demo == 'life-coaching'): ?>
				<button type="submit" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" class="lc-default-btn"><i class="bx bxs-cart-add"></i><?php echo esc_html( $product->single_add_to_cart_text() ); ?></button>

			<?php elseif($shop_details_style == 'style-ls'): ?>

				<ul class="fls-btn-area">
					<li>
						<button type="submit" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" class="fls-default-btn"><?php echo esc_html( $product->single_add_to_cart_text() ); ?><i class='bx bx-cart'></i></button>
					</li>
					<?php if ( class_exists( 'YITH_WCWL' ) ) { ?>
						<li class="fls-default-btn fls-wishlist-btn">
							<?php echo preg_replace("/<img[^>]+\>/i", " ", do_shortcode('[yith_wcwl_add_to_wishlist]')); ?>
						</li>
					<?php } ?>
				</ul>

			<?php endif; ?>
			
			<?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>
		</form>

    </div>

	<?php do_action( 'woocommerce_after_add_to_cart_form' ); ?>

<?php endif; ?>